// <copyright file="DriverOptionsMergeResult.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

namespace OpenQA.Selenium.Remote;

/// <summary>
/// Represents the result of merging multiple <see cref="DriverOptions"/>.
/// </summary>
public class DriverOptionsMergeResult
{
    /// <summary>
    /// Gets or sets a value indicating whether the DriverOptions would conflict when merged with another option.
    /// </summary>
    public bool IsMergeConflict { get; set; }

    /// <summary>
    /// Gets or sets the name of the name of the option that is in conflict, if any.
    /// </summary>
    public string? MergeConflictOptionName { get; set; }
}
